/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.engine.rmi.server.registry;

import java.util.HashMap;
import java.util.Map;

import org.objectweb.petals.component.framework.ComponentPropertiesManager;

/**
 * The RMI component properties.
 *
 * @author Nicolas SALATGE - eBMWebSourcing
 *
 */
public class RmiProperties {

    /**
     * the rmi port property.
     */
    public static final String RMI_PORT = "rmi.port";

    /**
     * Property: Verify if the internal registry server have to be activated.
     */
    public static final String RMI_EMBEDDED_REGISTRY = "rmi.embeddedregistry";

    /**
     * Property: the name of the rmi component context.
     */
    public static final String RMI_COMPONENT_CONTEXT_NAME = "rmi.componentcontextname";

    /**
     * the rmi port.
     */
    public static final int DEFAULT_RMI_PORT = 1099;

    /**
     * the internal registry server is active.
     */
    public static final boolean DEFAULT_RMI_EMBEDDED_REGISTRY = true;

    /**
     * the name of the rmi component context.
     */
    public static final String DEFAULT_RMI_COMPONENT_CONTEXT_NAME = "RMIComponentContext";

    /**
     * the properties manager.
     */
    private ComponentPropertiesManager propertiesManager;

    /**
     * Creates a new instance of {@link RmiProperties}.
     *
     * @param propertiesManager
     *         the properties
     */
    public RmiProperties(final ComponentPropertiesManager propertiesManager) {
        this.propertiesManager = propertiesManager;
    }

    /**
     * Get the RMI port.
     *
     * @return
     *         the rmi port
     */
    public int getRmiPort() {
        return Integer.parseInt(this.propertiesManager.getProperty(
                RmiProperties.RMI_PORT,
                Integer.toString(RmiProperties.DEFAULT_RMI_PORT)));
    }

    /**
     * Does the component have to start its internal rmi registry server.
     *
     * @return
     *     true if the component have to start its internal rmi registry server
     */
    public boolean isEmbeddedRegistry() {
        return Boolean.parseBoolean(this.propertiesManager.getProperty(
                RmiProperties.RMI_EMBEDDED_REGISTRY, Boolean
                        .toString(RmiProperties.DEFAULT_RMI_EMBEDDED_REGISTRY)));
    }


    public String getComponentContextName() {
        return this.propertiesManager.getProperty(
                RmiProperties.RMI_COMPONENT_CONTEXT_NAME,
                RmiProperties.DEFAULT_RMI_COMPONENT_CONTEXT_NAME);
    }

    /**
     * Get the default component properties.
     *
     * @return
     *       all the properties
     */
    protected static Map<String, String> getDefaultProperties() {
        Map<String, String> result = new HashMap<String, String>(3);
        result.put(RmiProperties.RMI_PORT,
                Integer.toString(RmiProperties.DEFAULT_RMI_PORT));
        result.put(RmiProperties.RMI_EMBEDDED_REGISTRY, Boolean
                .toString(RmiProperties.DEFAULT_RMI_EMBEDDED_REGISTRY));
        result.put(RmiProperties.RMI_COMPONENT_CONTEXT_NAME,
                RmiProperties.DEFAULT_RMI_COMPONENT_CONTEXT_NAME);

        return result;
    }

}
